FILENAME IN1 'e:\ethanol\aug99\MEGA_1.FIN';

OPTIONS LS=132;


DATA FINLMEGA;
INFILE IN1           MISSOVER;

INPUT STUDY $ VEHICLE $ FUEL $ MODEL_YR DRYBULB NOX CO THC
      NMHC AR BENZ ETBE ETOH MTBE TAME OL OX RV
      SU T5 T9 EXBENZ EX13BUTD EXFORMAL EXACTALD;

/* KEEP UNSTANDARDIZED VALUES */
oxygen=ox;
olef=ol;
sulfur=su;
rvp=rv;
t50=t5;
t90=t9;
arom=ar;

/* FUEL SPECIFICATIONS BASED ON THE ASTM STANDARDS */
IF RV GT 10 OR SU GT 1000 /* OR OX GT 4.0 */ OR
   T5 GT 250 OR T9 GT 374 OR DRYBULB LT 68 OR
   DRYBULB GT 95 THEN DELETE;


/* DELETE MISSING VALUES */
IF RV='.' OR AR='.' OR OL='.' OR SU='.' OR
   OX='.' OR T5='.' OR T9='.' THEN DELETE;


if ox gt 5.0 then delete;
else if ox gt 4.0 then flagox=1;
else flagox=0;

/* TECH GROUPS DEFINITION */
IF MODEL_YR LT 1975 THEN TECH =1;
   ELSE IF MODEL_YR LT 1981 THEN TECH = 2;
   ELSE IF MODEL_YR LT 1986 THEN TECH = 3;
   ELSE IF MODEL_YR LT 1994 THEN TECH = 4;
   ELSE TECH = 5;

/* CREATE NEW VARIABLES */
LN_THC = LOG (THC);
LN_NOX = LOG (NOX);
NEW    = compress( STUDY||VEHICLE);

/* TECH GROUPS SELECTION */
IF TECH = 4 OR TECH = 5;
mergevar=1;
RUN;

PROC means DATA=FINLMEGA mean std;
TITLE1 "FUEL PROPERTY MEANS AND STANDARD DEVIATIONS";
TITLE2 "POOLED DATA, TECH 4 AND 5 COMBINED";
VAR RV T5 T9 AR OL OX SU;
id mergevar;
where flagox=0;
output out=norms
mean=rvm t5m t9m arm olm oxm sum
std=rvs t5s t9s ars ols oxs sus
RUN;

data temp000;
merge finlmega norms;
by mergevar;
run;

/* Create TEMP000, the Tech 4 and 5 dataset without deletions
other than ARBATLOX fuel Y (deleted for 1994 analysis) and fuels
with parameters outside range of interest */

data arb dec99 may00;
set temp000;
rv=(rv-rvm)/rvs;
t5=(t5-t5m)/t5s;
t9=(t9-t9m)/t9s;
ar=(ar-arm)/ars;
ol=(ol-olm)/ols;
ox=(ox-oxm)/oxs;
su=(su-sum)/sus;

one=1;
    /* INDICATOR VARIABLE FOR TECH 5 */
        IF TECH=5 THEN I5=1;
        ELSE I5=0;

    /* INTERACTION TERMS */
        RVRV=RV*RV;
        RVT5=RV*T5;
        RVT9=RV*T9;
        RVAR=RV*AR;
        RVOL=RV*OL;
        RVSU=RV*SU;
        RVOX=RV*OX;
             T5T5=T5*T5;
             T5T9=T5*T9;
             T5AR=T5*AR;
             T5OL=T5*OL;
             T5SU=T5*SU;
             T5OX=T5*OX;
        T9T9=T9*T9;
        T9AR=T9*AR;
        T9OL=T9*OL;
        T9SU=T9*SU;
        T9OX=T9*OX;
             ARAR=AR*AR;
             AROL=AR*OL;
             ARSU=AR*SU;
             AROX=AR*OX;
        OLOL=OL*OL;
        OLSU=OL*SU;
        OLOX=OL*OX;
             SUSU=SU*SU;
             SUOX=SU*OX;
        OXOX=OX*OX;

    /* ADJUSTMENTS TO TECH 4 */
        I5_OX=I5*OX;
        I5_LS=I5*LS;
        I5_LSLS=I5*LS*LS;
        I5_SU=I5*SU;
        I5_SUSU=I5*SU*SU;
        I5_T5=I5*T5;
        I5_T5T9=I5*T5*T9;
        I5_T9=I5*T9;
        I5_T9T9=I5*T9*T9;

IF STUDY='GMCONFRM' THEN ETBE=0 ;
IF STUDY='GMCONFRM' THEN ETOH=0 ;
IF STUDY='GMCONFRM' THEN TAME=0 ;

*SPLIT CRC LOSULFUR STUDY INTO PART WITH OXYGEN FUELS AND PART WITHOUT;
*IF STUDY='CRCLOSUL' AND FUEL='S1' THEN STUDY='CRCLOSUO' ;
*IF STUDY='CRCLOSUL' AND FUEL='S2' THEN STUDY='CRCLOSUO' ;

IF STUDY = 'ARBATLOX' AND FUEL = 'Y' THEN DELETE ;
IF RV=. OR AR=. OR OL=. OR SU=. OR
   OX=. OR T5=. OR T9=. THEN DELETE;


/* Flag studies to be deleted */

exclude=0;
IF STUDY='ARBMSD96' THEN EXCLUDE=1 ;
IF STUDY='EPA_PH3' AND VEHICLE ='I' THEN EXCLUDE=1 ;
IF STUDY='ARBETOH' THEN EXCLUDE=1 ;
IF STUDY='CHEVOX99' THEN EXCLUDE=1;

*THE FOLLOWING ARE OBSERVATIONS THAT ARE LISTED TWICE IN THE DATA
BASE (IN ATL1 AND ATL2) AND MAY BE DELETED LATER ;
IF STUDY='EPA_ATL2' AND FUEL='C' THEN EXCLUDE=2 ;
IF STUDY='EPA_ATL2' AND FUEL='D' THEN EXCLUDE=2 ;
IF STUDY='EPA_ATL2' AND FUEL='E' THEN EXCLUDE=2 ;
IF STUDY='EPA_ATL2' AND FUEL='F' THEN EXCLUDE=2 ;
IF STUDY='EPA_ATL2' AND FUEL='G' THEN EXCLUDE=2 ;
IF STUDY='EPA_ATL2' AND FUEL='H' THEN EXCLUDE=2 ;


    /* REMOVE TECH 4 HIGH INFLUENCE VEHICLES */
        IF TECH=4 AND STUDY='ARBMSD96' THEN EXCLUDE=1;
        IF TECH=4 AND STUDY='EPA_PH3' AND VEHICLE='I' THEN EXCLUDE=1;

    /* REMOVE TECH 4 CHEVRON DATA */
        IF TECH=4 AND STUDY='CHEVOX99' THEN EXCLUDE=1;

    /* REMOVE TECH 5 SUSPECT VEHICLES FROM CRC LOW SULFUR STUDY */
*        IF TECH=5 AND STUDY='CRCLOSUL' AND VEHICLE='Z1R' THEN EXCLUDE=1;
*        IF TECH=5 AND STUDY='CRCLOSUL' AND VEHICLE='Z2R' THEN EXCLUDE=1;
*        IF TECH=5 AND STUDY='CRCLOSUL' AND VEHICLE='Z1A' THEN EXCLUDE=1;
*        IF TECH=5 AND STUDY='CRCLOSUL' AND VEHICLE='Z2A' THEN EXCLUDE=1;
*        IF TECH=5 AND STUDY='CRCLOSU0' AND VEHICLE='Z1R' THEN EXCLUDE=1;
*        IF TECH=5 AND STUDY='CRCLOSU0' AND VEHICLE='Z2R' THEN EXCLUDE=1;
*        IF TECH=5 AND STUDY='CRCLOSU0' AND VEHICLE='Z1A' THEN EXCLUDE=1;
*        IF TECH=5 AND STUDY='CRCLOSU0' AND VEHICLE='Z2A' THEN EXCLUDE=1;

    /* REMOVE ARB ETHANOL STUDY COMPLETELY*/
        IF TECH=4 AND STUDY='ARBETOH' THEN EXCLUDE=1;
        IF TECH=5 AND STUDY='ARBETOH' THEN EXCLUDE=1;
if tech=4;
all=1;
if (exclude=0 or exclude=2) and flagox=0 then output arb;
if exclude=0 and flagox=0 then output dec99;
if exclude=0 then output may00;
run;

%macro addwt(dataset);

/* Define High Emitters based on mean across fuels of mean across tests */

proc sort data=&dataset;
by tech new fuel;
run;

proc means data=&dataset noprint;
by tech new fuel;
var thc nox co nmhc;
id study vehicle model_yr;
output out=fuelmean mean= n=nthc nnox nco nnmhc;
run;

proc means data=fuelmean noprint;
by tech new;
id study vehicle model_yr;
var thc nox co nmhc nthc nnox nco nnmhc;
output out=vehmean
mean=thcmean noxmean comean nmhcmean
min=thcmin noxmin comin nmhcmin
max=thcmax noxmax comax nmhcmax
sum=sum1 sum2 sum3 sum4 thccnt noxcnt cocnt nmhccnt     /* numbers of measurements per vehicle inc. reps */
n=thcfuel noxfuel cofuel nmhcfuel /* numbers of fuels tested */
;
run;

/* Earlier draft Higher emitter definitions
we have mainly worked with ih
*/

data vehmean;
set vehmean;
keep tech new study vehicle model_yr
thcmean noxmean comean nmhcmean
thcmin noxmin comin nmhcmin
thcmax noxmax comax nmhcmax
thccnt noxcnt cocnt nmhccnt
thcfuel noxfuel cofuel nmhcfuel
ih in ic thcmean2;
thcmean2=thcmean*2;
* if min(thccnt,noxcnt,cocnt,nmhccnt) ne max(thccnt,noxcnt,cocnt,nmhccnt)
and nmhccnt ne 0 then put _all_;
* if min(thcfuel,noxfuel,cofuel,nmhcfuel) ne max(thcfuel,noxfuel,cofuel,nmhcfuel)
and nmhccnt ne 0 then put _all_;
if thcmean = . or tech = 5 then ih=0;
else if thcmean > 0.41 and tech = 4 then ih=1;
else if thcmean <= 0.41 and tech = 4 then ih=0;
if noxmean = . or tech = 5 then in=0;
else if noxmean > 0.4 and tech = 4 then in=1;
else if noxmean <= 0.4 and tech = 4 then in=0;
if comean = . or tech = 5 then ic=0;
else if comean > 1 and tech = 4 then ic=1;
else if comean <= 1 and tech = 4 then ic=0;
if thcfuel ne noxfuel then put _all_;
run;


/* read in weights  */

data weights;
length new $ 12 hccat $ 20 noxcat $ 20;
infile "e:\ethanol\aug99\manmod3.csv" delimiter=',';
input tech new $ sstudy $ svehicle $ smod_yr
manmod thc2000 nox2000 co2000 thc2005 nox2005 co2005 hccat noxcat;
run;

proc means data=weights n mean sum;
var
manmod thc2000 nox2000 co2000 thc2005 nox2005 co2005;
run;

/*
proc print data=vehmean;
var tech new vehicle study;
run;

proc print data=weights;
var tech new svehicle sstudy;
run;
*/

proc sort data=weights;
by tech new;
run;


data vehmean;
merge vehmean weights;
by tech new;
if study ne sstudy or vehicle ne svehicle
or model_yr ne smod_yr then put _all_;
run;

/*
proc print data=vehmean;
run;
*/

data &dataset;
merge &dataset vehmean;
by tech new;
run;

data &dataset;
merge &dataset fuelmean(keep=tech new fuel nthc nnox);
by tech new fuel;
run;



data &dataset; set &dataset;
/* THC */

/* Main higher emitter terms */
ih_rv=ih*rv;
ih_ox=ih*ox;
ih_ol=ih*ol;
ih_su=ih*su;
ih_t5=ih*t5;
ih_t9=ih*t9;
ih_ar=ih*ar;
/* higher emitter interactions */
        ih_RVRV=ih*RV*RV;
        ih_RVT5=ih*RV*T5;
        ih_RVT9=ih*RV*T9;
        ih_RVAR=ih*RV*AR;
        ih_RVOL=ih*RV*OL;
        ih_RVSU=ih*RV*SU;
        ih_RVOX=ih*RV*OX;
             ih_T5T5=ih*T5*T5;
             ih_T5T9=ih*T5*T9;
             ih_T5AR=ih*T5*AR;
             ih_T5OL=ih*T5*OL;
             ih_T5SU=ih*T5*SU;
             ih_T5OX=ih*T5*OX;
        ih_T9T9=ih*T9*T9;
        ih_T9AR=ih*T9*AR;
        ih_T9OL=ih*T9*OL;
        ih_T9SU=ih*T9*SU;
        ih_T9OX=ih*T9*OX;
             ih_ARAR=ih*AR*AR;
             ih_AROL=ih*AR*OL;
             ih_ARSU=ih*AR*SU;
             ih_AROX=ih*AR*OX;
        ih_OLOL=ih*OL*OL;
        ih_OLSU=ih*OL*SU;
        ih_OLOX=ih*OL*OX;
             ih_SUSU=ih*SU*SU;
             ih_SUOX=ih*SU*OX;
        ih_OXOX=ih*OX*OX;

/* NOX */

/* Main higher emitter terms */
in_rv=in*rv;
in_ox=in*ox;
in_ol=in*ol;
in_su=in*su;
in_t5=in*t5;
in_t9=in*t9;
in_ar=in*ar;
/* higher emitter interactions */
        in_RVRV=in*RV*RV;
        in_RVT5=in*RV*T5;
        in_RVT9=in*RV*T9;
        in_RVAR=in*RV*AR;
        in_RVOL=in*RV*OL;
        in_RVSU=in*RV*SU;
        in_RVOX=in*RV*OX;
             in_T5T5=in*T5*T5;
             in_T5T9=in*T5*T9;
             in_T5AR=in*T5*AR;
             in_T5OL=in*T5*OL;
             in_T5SU=in*T5*SU;
             in_T5OX=in*T5*OX;
        in_T9T9=in*T9*T9;
        in_T9AR=in*T9*AR;
        in_T9OL=in*T9*OL;
        in_T9SU=in*T9*SU;
        in_T9OX=in*T9*OX;
             in_ARAR=in*AR*AR;
             in_AROL=in*AR*OL;
             in_ARSU=in*AR*SU;
             in_AROX=in*AR*OX;
        in_OLOL=in*OL*OL;
        in_OLSU=in*OL*SU;
        in_OLOX=in*OL*OX;
             in_SUSU=in*SU*SU;
             in_SUOX=in*SU*OX;
        in_OXOX=in*OX*OX;

/* CO */

/* Main higher emitter terms */
ic_rv=ic*rv;
ic_ox=ic*ox;
ic_ol=ic*ol;
ic_su=ic*su;
ic_t5=ic*t5;
ic_t9=ic*t9;
ic_ar=ic*ar;
/* higher emitter interactions */
        ic_RVRV=ic*RV*RV;
        ic_RVT5=ic*RV*T5;
        ic_RVT9=ic*RV*T9;
        ic_RVAR=ic*RV*AR;
        ic_RVOL=ic*RV*OL;
        ic_RVSU=ic*RV*SU;
        ic_RVOX=ic*RV*OX;
             ic_T5T5=ic*T5*T5;
             ic_T5T9=ic*T5*T9;
             ic_T5AR=ic*T5*AR;
             ic_T5OL=ic*T5*OL;
             ic_T5SU=ic*T5*SU;
             ic_T5OX=ic*T5*OX;
        ic_T9T9=ic*T9*T9;
        ic_T9AR=ic*T9*AR;
        ic_T9OL=ic*T9*OL;
        ic_T9SU=ic*T9*SU;
        ic_T9OX=ic*T9*OX;
             ic_ARAR=ic*AR*AR;
             ic_AROL=ic*AR*OL;
             ic_ARSU=ic*AR*SU;
             ic_AROX=ic*AR*OX;
        ic_OLOL=ic*OL*OL;
        ic_OLSU=ic*OL*SU;
        ic_OLOX=ic*OL*OX;
             ic_SUSU=ic*SU*SU;
             ic_SUOX=ic*SU*OX;
        ic_OXOX=ic*OX*OX;

/* compute weights */
wgtnox00=nox2000/noxfuel/nnox;
wgtthc00=thc2000/thcfuel/nthc;
wgtnox05=nox2005/noxfuel/nnox;
wgtthc05=thc2005/thcfuel/nthc;
weight=10*nox2005;
one=1;
obs=_n_;
if noxcat = "Normal" then noxcat2 = "Normal";
else noxcat2="Higher";

/* create random effects terms = fixed / sqrt(weight) */

w =    1 / sqrt(weight);
rvw = rv / sqrt(weight);
t5w = t5 / sqrt(weight);
t9w = t9 / sqrt(weight);
olw = ol / sqrt(weight);
oxw = ox / sqrt(weight);
suw = su / sqrt(weight);
arw = ar / sqrt(weight);
t5t5w = t5t5 / sqrt(weight);
t9arw = t9ar / sqrt(weight);
t9oxw = t9ox / sqrt(weight);
t9t9w = t9t9 / sqrt(weight);
ararw = arar / sqrt(weight);
t9suw = t9su / sqrt(weight);
susuw = susu / sqrt(weight);
rvrvw = rvrv / sqrt(weight);

oxoxw = oxox / sqrt(weight);
aroxw = arox / sqrt(weight);
rvoxw = rvox / sqrt(weight);

run;


proc means data=&dataset n mean sum std min max;
var wgtnox00 wgtthc00 wgtnox05 wgtthc05 ln_nox;
title "&dataset";
run;


proc print data=&dataset(obs=20);
var new fuel wgtnox00 wgtthc00 wgtnox05 wgtthc05 weight w rv rvw su suw t9su t9suw;
title "&dataset";
run;


%mend addwt;

%addwt(may00)

data higher normal;
set may00;
if noxcat2="Higher" then output higher;
else output normal;
run;


/* Run mixed models */


data base;

rvpm=8.308910;
t50m=207.019049;
t90m=311.785331;
aromm=27.849881;
olefm=6.806801;
sulfurm=180.770373;
oxygenm=1.355654;
rvps=0.846737;
t50s=17.195294;
t90s=21.595186;
aroms=7.004743;
olefs=4.665131;
sulfurs=147.006156;
oxygens=1.224639;

rvpb=(6.9-rvpm)/rvps;
sulfurb=(20-sulfurm)/sulfurs;
oxygenb=(2-oxygenm)/oxygens;
t50b=(211-t50m)/t50s;
t90b=(305-t90m)/t90s;
aromb=(25-aromm)/aroms;
olefb=(6-olefm)/olefs;
oxoxb=oxygenb*oxygenb;
rvrvb=rvpb*rvpb;
rvarb=rvpb*aromb;
rvolb=rvpb*olefb;
rvt9b=rvpb*t90b;
arsub=aromb*sulfurb;
ararb=aromb*aromb;
ololb=olefb*olefb;
susub=sulfurb*sulfurb;
t9sub=t90b*sulfurb;
aroxb=aromb*oxygenb;
rvoxb=rvpb*oxygenb;
rvsub=rvpb*sulfurb;
rvt5b=rvpb*t50b;
arolb=aromb*olefb;
t5arb=t50b*aromb;
t9arb=t90b*aromb;
oloxb=olefb*oxygenb;
olt5b=olefb*t50b;
t9olb=olefb*t90b;
olsub=olefb*sulfurb;
t5oxb=t50b*oxygenb;
t5t9b=t50b*t90b;
t5sub=t50b*sulfurb;
t5t5b=t50b*t50b;
t9oxb=t90b*oxygenb;
t9t9b=t90b*t90b;
suoxb=sulfurb*oxygenb;
run;

data oxygen;
set base;

do i=0 to 70;
oxygen=i/20;

rvp1=(6.9-rvpm)/rvps;
sulfur1=(20-sulfurm)/sulfurs;
oxygen1=(oxygen-oxygenm)/oxygens;
t501=(211-t50m)/t50s;
t901=(305-t90m)/t90s;
arom1=(25-aromm)/aroms;
olef1=(6-olefm)/olefs;
oxox1=oxygen1*oxygen1;
rvrv1=rvp1*rvp1;
rvar1=rvp1*arom1;
rvol1=rvp1*olef1;
rvt91=rvp1*t901;
arsu1=arom1*sulfur1;
arar1=arom1*arom1;
olol1=olef1*olef1;
susu1=sulfur1*sulfur1;
t9su1=t901*sulfur1;
arox1=arom1*oxygen1;
rvox1=rvp1*oxygen1;
rvsu1=rvp1*sulfur1;
rvt51=rvp1*t501;
arol1=arom1*olef1;
t5ar1=t501*arom1;
t9ar1=t901*arom1;
olox1=olef1*oxygen1;
olt51=olef1*t501;
t9ol1=olef1*t901;
olsu1=olef1*sulfur1;
t5ox1=t501*oxygen1;
t5t91=t501*t901;
t5su1=t501*sulfur1;
t5t51=t501*t501;
t9ox1=t901*oxygen1;
t9t91=t901*t901;
suox1=sulfur1*oxygen1;

rvp4=rvp1-rvpb;
sulfur4=sulfur1-sulfurb;
oxygen4=oxygen1-oxygenb;
t504=t501-t50b;
t904=t901-t90b;
arom4=arom1-aromb;
olef4=olef1-olefb;
oxox4=oxox1-oxoxb;
rvrv4=rvrv1-rvrvb;
rvar4=rvar1-rvarb;
rvol4=rvol1-rvolb;
rvt94=rvt91-rvt9b;
arsu4=arsu1-arsub;
arar4=arar1-ararb;
olol4=olol1-ololb;
susu4=susu1-susub;
t9su4=t9su1-t9sub;
arox4=arox1-aroxb;
rvox4=rvox1-rvoxb;
rvsu4=rvsu1-rvsub;
rvt54=rvt51-rvt5b;
arol4=arol1-arolb;
t5ar4=t5ar1-t5arb;
t9ar4=t9ar1-t9arb;
olox4=olox1-oloxb;
olt54=olt51-olt5b;
t9ol4=t9ol1-t9olb;
olsu4=olsu1-olsub;
t5ox4=t5ox1-t5oxb;
t5t94=t5t91-t5t9b;
t5su4=t5su1-t5sub;
t5t54=t5t51-t5t5b;
t9ox4=t9ox1-t9oxb;
t9t94=t9t91-t9t9b;
suox4=suox1-suoxb;



output;
end;
run;

data rvp;
set base;

do i=640 to 760;
rvp=i/100;

rvp1=(rvp-rvpm)/rvps;
sulfur1=(20-sulfurm)/sulfurs;
oxygen1=(2-oxygenm)/oxygens;
t501=(211-t50m)/t50s;
t901=(305-t90m)/t90s;
arom1=(25-aromm)/aroms;
olef1=(6-olefm)/olefs;
oxox1=oxygen1*oxygen1;
rvrv1=rvp1*rvp1;
rvar1=rvp1*arom1;
rvol1=rvp1*olef1;
rvt91=rvp1*t901;
arsu1=arom1*sulfur1;
arar1=arom1*arom1;
olol1=olef1*olef1;
susu1=sulfur1*sulfur1;
t9su1=t901*sulfur1;
arox1=arom1*oxygen1;
rvox1=rvp1*oxygen1;
rvsu1=rvp1*sulfur1;
rvt51=rvp1*t501;
arol1=arom1*olef1;
t5ar1=t501*arom1;
t9ar1=t901*arom1;
olox1=olef1*oxygen1;
olt51=olef1*t501;
t9ol1=olef1*t901;
olsu1=olef1*sulfur1;
t5ox1=t501*oxygen1;
t5t91=t501*t901;
t5su1=t501*sulfur1;
t5t51=t501*t501;
t9ox1=t901*oxygen1;
t9t91=t901*t901;
suox1=sulfur1*oxygen1;
rvp4=rvp1-rvpb;
sulfur4=sulfur1-sulfurb;
oxygen4=oxygen1-oxygenb;
t504=t501-t50b;
t904=t901-t90b;
arom4=arom1-aromb;
olef4=olef1-olefb;
oxox4=oxox1-oxoxb;
rvrv4=rvrv1-rvrvb;
rvar4=rvar1-rvarb;
rvol4=rvol1-rvolb;
rvt94=rvt91-rvt9b;
arsu4=arsu1-arsub;
arar4=arar1-ararb;
olol4=olol1-ololb;
susu4=susu1-susub;
t9su4=t9su1-t9sub;
arox4=arox1-aroxb;
rvox4=rvox1-rvoxb;
rvsu4=rvsu1-rvsub;
rvt54=rvt51-rvt5b;
arol4=arol1-arolb;
t5ar4=t5ar1-t5arb;
t9ar4=t9ar1-t9arb;
olox4=olox1-oloxb;
olt54=olt51-olt5b;
t9ol4=t9ol1-t9olb;
olsu4=olsu1-olsub;
t5ox4=t5ox1-t5oxb;
t5t94=t5t91-t5t9b;
t5su4=t5su1-t5sub;
t5t54=t5t51-t5t5b;
t9ox4=t9ox1-t9oxb;
t9t94=t9t91-t9t9b;
suox4=suox1-suoxb;

output;
end;
run;

data olef;
set base;

do i=0 to 50;
olef=i/5;

rvp1=(6.9-rvpm)/rvps;
sulfur1=(20-sulfurm)/sulfurs;
oxygen1=(2-oxygenm)/oxygens;
t501=(211-t50m)/t50s;
t901=(305-t90m)/t90s;
arom1=(25-aromm)/aroms;
olef1=(olef-olefm)/olefs;
oxox1=oxygen1*oxygen1;
rvrv1=rvp1*rvp1;
rvar1=rvp1*arom1;
rvol1=rvp1*olef1;
rvt91=rvp1*t901;
arsu1=arom1*sulfur1;
arar1=arom1*arom1;
olol1=olef1*olef1;
susu1=sulfur1*sulfur1;
t9su1=t901*sulfur1;
arox1=arom1*oxygen1;
rvox1=rvp1*oxygen1;
rvsu1=rvp1*sulfur1;
rvt51=rvp1*t501;
arol1=arom1*olef1;
t5ar1=t501*arom1;
t9ar1=t901*arom1;
olox1=olef1*oxygen1;
olt51=olef1*t501;
t9ol1=olef1*t901;
olsu1=olef1*sulfur1;
t5ox1=t501*oxygen1;
t5t91=t501*t901;
t5su1=t501*sulfur1;
t5t51=t501*t501;
t9ox1=t901*oxygen1;
t9t91=t901*t901;
suox1=sulfur1*oxygen1;
rvp4=rvp1-rvpb;
sulfur4=sulfur1-sulfurb;
oxygen4=oxygen1-oxygenb;
t504=t501-t50b;
t904=t901-t90b;
arom4=arom1-aromb;
olef4=olef1-olefb;
oxox4=oxox1-oxoxb;
rvrv4=rvrv1-rvrvb;
rvar4=rvar1-rvarb;
rvol4=rvol1-rvolb;
rvt94=rvt91-rvt9b;
arsu4=arsu1-arsub;
arar4=arar1-ararb;
olol4=olol1-ololb;
susu4=susu1-susub;
t9su4=t9su1-t9sub;
arox4=arox1-aroxb;
rvox4=rvox1-rvoxb;
rvsu4=rvsu1-rvsub;
rvt54=rvt51-rvt5b;
arol4=arol1-arolb;
t5ar4=t5ar1-t5arb;
t9ar4=t9ar1-t9arb;
olox4=olox1-oloxb;
olt54=olt51-olt5b;
t9ol4=t9ol1-t9olb;
olsu4=olsu1-olsub;
t5ox4=t5ox1-t5oxb;
t5t94=t5t91-t5t9b;
t5su4=t5su1-t5sub;
t5t54=t5t51-t5t5b;
t9ox4=t9ox1-t9oxb;
t9t94=t9t91-t9t9b;
suox4=suox1-suoxb;

output;
end;
run;

data sulfur;
set base;

do i=0 to 80;
sulfur=i;

rvp1=(6.9-rvpm)/rvps;
sulfur1=(sulfur-sulfurm)/sulfurs;
oxygen1=(2-oxygenm)/oxygens;
t501=(211-t50m)/t50s;
t901=(305-t90m)/t90s;
arom1=(25-aromm)/aroms;
olef1=(6-olefm)/olefs;
oxox1=oxygen1*oxygen1;
rvrv1=rvp1*rvp1;
rvar1=rvp1*arom1;
rvol1=rvp1*olef1;
rvt91=rvp1*t901;
arsu1=arom1*sulfur1;
arar1=arom1*arom1;
olol1=olef1*olef1;
susu1=sulfur1*sulfur1;
t9su1=t901*sulfur1;
arox1=arom1*oxygen1;
rvox1=rvp1*oxygen1;
rvsu1=rvp1*sulfur1;
rvt51=rvp1*t501;
arol1=arom1*olef1;
t5ar1=t501*arom1;
t9ar1=t901*arom1;
olox1=olef1*oxygen1;
olt51=olef1*t501;
t9ol1=olef1*t901;
olsu1=olef1*sulfur1;
t5ox1=t501*oxygen1;
t5t91=t501*t901;
t5su1=t501*sulfur1;
t5t51=t501*t501;
t9ox1=t901*oxygen1;
t9t91=t901*t901;
suox1=sulfur1*oxygen1;
rvp4=rvp1-rvpb;
sulfur4=sulfur1-sulfurb;
oxygen4=oxygen1-oxygenb;
t504=t501-t50b;
t904=t901-t90b;
arom4=arom1-aromb;
olef4=olef1-olefb;
oxox4=oxox1-oxoxb;
rvrv4=rvrv1-rvrvb;
rvar4=rvar1-rvarb;
rvol4=rvol1-rvolb;
rvt94=rvt91-rvt9b;
arsu4=arsu1-arsub;
arar4=arar1-ararb;
olol4=olol1-ololb;
susu4=susu1-susub;
t9su4=t9su1-t9sub;
arox4=arox1-aroxb;
rvox4=rvox1-rvoxb;
rvsu4=rvsu1-rvsub;
rvt54=rvt51-rvt5b;
arol4=arol1-arolb;
t5ar4=t5ar1-t5arb;
t9ar4=t9ar1-t9arb;
olox4=olox1-oloxb;
olt54=olt51-olt5b;
t9ol4=t9ol1-t9olb;
olsu4=olsu1-olsub;
t5ox4=t5ox1-t5oxb;
t5t94=t5t91-t5t9b;
t5su4=t5su1-t5sub;
t5t54=t5t51-t5t5b;
t9ox4=t9ox1-t9oxb;
t9t94=t9t91-t9t9b;
suox4=suox1-suoxb;

output;
end;
run;

data arom;
set base;

do i=20 to 70;
arom=i/2;

rvp1=(6.9-rvpm)/rvps;
sulfur1=(20-sulfurm)/sulfurs;
oxygen1=(2-oxygenm)/oxygens;
t501=(211-t50m)/t50s;
t901=(305-t90m)/t90s;
arom1=(arom-aromm)/aroms;
olef1=(6-olefm)/olefs;
oxox1=oxygen1*oxygen1;
rvrv1=rvp1*rvp1;
rvar1=rvp1*arom1;
rvol1=rvp1*olef1;
rvt91=rvp1*t901;
arsu1=arom1*sulfur1;
arar1=arom1*arom1;
olol1=olef1*olef1;
susu1=sulfur1*sulfur1;
t9su1=t901*sulfur1;
arox1=arom1*oxygen1;
rvox1=rvp1*oxygen1;
rvsu1=rvp1*sulfur1;
rvt51=rvp1*t501;
arol1=arom1*olef1;
t5ar1=t501*arom1;
t9ar1=t901*arom1;
olox1=olef1*oxygen1;
olt51=olef1*t501;
t9ol1=olef1*t901;
olsu1=olef1*sulfur1;
t5ox1=t501*oxygen1;
t5t91=t501*t901;
t5su1=t501*sulfur1;
t5t51=t501*t501;
t9ox1=t901*oxygen1;
t9t91=t901*t901;
suox1=sulfur1*oxygen1;
rvp4=rvp1-rvpb;
sulfur4=sulfur1-sulfurb;
oxygen4=oxygen1-oxygenb;
t504=t501-t50b;
t904=t901-t90b;
arom4=arom1-aromb;
olef4=olef1-olefb;
oxox4=oxox1-oxoxb;
rvrv4=rvrv1-rvrvb;
rvar4=rvar1-rvarb;
rvol4=rvol1-rvolb;
rvt94=rvt91-rvt9b;
arsu4=arsu1-arsub;
arar4=arar1-ararb;
olol4=olol1-ololb;
susu4=susu1-susub;
t9su4=t9su1-t9sub;
arox4=arox1-aroxb;
rvox4=rvox1-rvoxb;
rvsu4=rvsu1-rvsub;
rvt54=rvt51-rvt5b;
arol4=arol1-arolb;
t5ar4=t5ar1-t5arb;
t9ar4=t9ar1-t9arb;
olox4=olox1-oloxb;
olt54=olt51-olt5b;
t9ol4=t9ol1-t9olb;
olsu4=olsu1-olsub;
t5ox4=t5ox1-t5oxb;
t5t94=t5t91-t5t9b;
t5su4=t5su1-t5sub;
t5t54=t5t51-t5t5b;
t9ox4=t9ox1-t9oxb;
t9t94=t9t91-t9t9b;
suox4=suox1-suoxb;

output;
end;
run;

data t50;
set base;

do i=180 to 230;
t50=i;

rvp1=(6.9-rvpm)/rvps;
sulfur1=(20-sulfurm)/sulfurs;
oxygen1=(2-oxygenm)/oxygens;
t501=(t50-t50m)/t50s;
t901=(305-t90m)/t90s;
arom1=(25-aromm)/aroms;
olef1=(6-olefm)/olefs;
oxox1=oxygen1*oxygen1;
rvrv1=rvp1*rvp1;
rvar1=rvp1*arom1;
rvol1=rvp1*olef1;
rvt91=rvp1*t901;
arsu1=arom1*sulfur1;
arar1=arom1*arom1;
olol1=olef1*olef1;
susu1=sulfur1*sulfur1;
t9su1=t901*sulfur1;
arox1=arom1*oxygen1;
rvox1=rvp1*oxygen1;
rvsu1=rvp1*sulfur1;
rvt51=rvp1*t501;
arol1=arom1*olef1;
t5ar1=t501*arom1;
t9ar1=t901*arom1;
olox1=olef1*oxygen1;
olt51=olef1*t501;
t9ol1=olef1*t901;
olsu1=olef1*sulfur1;
t5ox1=t501*oxygen1;
t5t91=t501*t901;
t5su1=t501*sulfur1;
t5t51=t501*t501;
t9ox1=t901*oxygen1;
t9t91=t901*t901;
suox1=sulfur1*oxygen1;
rvp4=rvp1-rvpb;
sulfur4=sulfur1-sulfurb;
oxygen4=oxygen1-oxygenb;
t504=t501-t50b;
t904=t901-t90b;
arom4=arom1-aromb;
olef4=olef1-olefb;
oxox4=oxox1-oxoxb;
rvrv4=rvrv1-rvrvb;
rvar4=rvar1-rvarb;
rvol4=rvol1-rvolb;
rvt94=rvt91-rvt9b;
arsu4=arsu1-arsub;
arar4=arar1-ararb;
olol4=olol1-ololb;
susu4=susu1-susub;
t9su4=t9su1-t9sub;
arox4=arox1-aroxb;
rvox4=rvox1-rvoxb;
rvsu4=rvsu1-rvsub;
rvt54=rvt51-rvt5b;
arol4=arol1-arolb;
t5ar4=t5ar1-t5arb;
t9ar4=t9ar1-t9arb;
olox4=olox1-oloxb;
olt54=olt51-olt5b;
t9ol4=t9ol1-t9olb;
olsu4=olsu1-olsub;
t5ox4=t5ox1-t5oxb;
t5t94=t5t91-t5t9b;
t5su4=t5su1-t5sub;
t5t54=t5t51-t5t5b;
t9ox4=t9ox1-t9oxb;
t9t94=t9t91-t9t9b;
suox4=suox1-suoxb;

output;
end;
run;

data t90;
set base;

do i=280 to 330;
t90=i;

rvp1=(6.9-rvpm)/rvps;
sulfur1=(20-sulfurm)/sulfurs;
oxygen1=(2-oxygenm)/oxygens;
t501=(211-t50m)/t50s;
t901=(t90-t90m)/t90s;
arom1=(25-aromm)/aroms;
olef1=(6-olefm)/olefs;
oxox1=oxygen1*oxygen1;
rvrv1=rvp1*rvp1;
rvar1=rvp1*arom1;
rvol1=rvp1*olef1;
rvt91=rvp1*t901;
arsu1=arom1*sulfur1;
arar1=arom1*arom1;
olol1=olef1*olef1;
susu1=sulfur1*sulfur1;
t9su1=t901*sulfur1;
arox1=arom1*oxygen1;
rvox1=rvp1*oxygen1;
rvsu1=rvp1*sulfur1;
rvt51=rvp1*t501;
arol1=arom1*olef1;
t5ar1=t501*arom1;
t9ar1=t901*arom1;
olox1=olef1*oxygen1;
olt51=olef1*t501;
t9ol1=olef1*t901;
olsu1=olef1*sulfur1;
t5ox1=t501*oxygen1;
t5t91=t501*t901;
t5su1=t501*sulfur1;
t5t51=t501*t501;
t9ox1=t901*oxygen1;
t9t91=t901*t901;
suox1=sulfur1*oxygen1;
rvp4=rvp1-rvpb;
sulfur4=sulfur1-sulfurb;
oxygen4=oxygen1-oxygenb;
t504=t501-t50b;
t904=t901-t90b;
arom4=arom1-aromb;
olef4=olef1-olefb;
oxox4=oxox1-oxoxb;
rvrv4=rvrv1-rvrvb;
rvar4=rvar1-rvarb;
rvol4=rvol1-rvolb;
rvt94=rvt91-rvt9b;
arsu4=arsu1-arsub;
arar4=arar1-ararb;
olol4=olol1-ololb;
susu4=susu1-susub;
t9su4=t9su1-t9sub;
arox4=arox1-aroxb;
rvox4=rvox1-rvoxb;
rvsu4=rvsu1-rvsub;
rvt54=rvt51-rvt5b;
arol4=arol1-arolb;
t5ar4=t5ar1-t5arb;
t9ar4=t9ar1-t9arb;
olox4=olox1-oloxb;
olt54=olt51-olt5b;
t9ol4=t9ol1-t9olb;
olsu4=olsu1-olsub;
t5ox4=t5ox1-t5oxb;
t5t94=t5t91-t5t9b;
t5su4=t5su1-t5sub;
t5t54=t5t51-t5t5b;
t9ox4=t9ox1-t9oxb;
t9t94=t9t91-t9t9b;
suox4=suox1-suoxb;

output;
end;
run;

data _null_;
set oxygen;
i=_n_-1;
call symput(  'rv1'||left(i),trim(left(put(rvp4,best12.))));
call symput(  'su1'||left(i),trim(left(put(sulfur4,best12.))));
call symput(  'ox1'||left(i),trim(left(put(oxygen4,best12.))));
call symput(  't51'||left(i),trim(left(put(t504,best12.))));
call symput(  't91'||left(i),trim(left(put(t904,best12.))));
call symput(  'ar1'||left(i),trim(left(put(arom4,best12.))));
call symput(  'ol1'||left(i),trim(left(put(olef4,best12.))));
call symput('oxox1'||left(i),trim(left(put(oxox4,best12.))));
call symput('rvrv1'||left(i),trim(left(put(rvrv4,best12.))));
call symput('rvar1'||left(i),trim(left(put(rvar4,best12.))));
call symput('rvol1'||left(i),trim(left(put(rvol4,best12.))));
call symput('rvt91'||left(i),trim(left(put(rvt94,best12.))));
call symput('arsu1'||left(i),trim(left(put(arsu4,best12.))));
call symput('arar1'||left(i),trim(left(put(arar4,best12.))));
call symput('olol1'||left(i),trim(left(put(olol4,best12.))));
call symput('susu1'||left(i),trim(left(put(susu4,best12.))));
call symput('t9su1'||left(i),trim(left(put(t9su4,best12.))));
call symput('rvsu1'||left(i),trim(left(put(rvsu4,best12.))));
call symput('rvt51'||left(i),trim(left(put(rvt54,best12.))));
call symput('arol1'||left(i),trim(left(put(arol4,best12.))));
call symput('t5ar1'||left(i),trim(left(put(t5ar4,best12.))));
call symput('t9ar1'||left(i),trim(left(put(t9ar4,best12.))));
call symput('rvox1'||left(i),trim(left(put(rvox4,best12.))));
call symput('olox1'||left(i),trim(left(put(olox4,best12.))));
call symput('olt51'||left(i),trim(left(put(olt54,best12.))));
call symput('t9ol1'||left(i),trim(left(put(t9ol4,best12.))));
call symput('olsu1'||left(i),trim(left(put(olsu4,best12.))));
call symput('t5ox1'||left(i),trim(left(put(t5ox4,best12.))));
call symput('t5t91'||left(i),trim(left(put(t5t94,best12.))));
call symput('t5su1'||left(i),trim(left(put(t5su4,best12.))));
call symput('t5t51'||left(i),trim(left(put(t5t54,best12.))));
call symput('t9ox1'||left(i),trim(left(put(t9ox4,best12.))));
call symput('t9t91'||left(i),trim(left(put(t9t94,best12.))));
call symput('suox1'||left(i),trim(left(put(suox4,best12.))));
call symput('arox1'||left(i),trim(left(put(arox4,best12.))));

run;

data _null_;
set rvp;
i=_n_-1;
call symput(  'rv2'||left(i),trim(left(put(rvp4,best12.))));
call symput(  'su2'||left(i),trim(left(put(sulfur4,best12.))));
call symput(  'ox2'||left(i),trim(left(put(oxygen4,best12.))));
call symput(  't52'||left(i),trim(left(put(t504,best12.))));
call symput(  't92'||left(i),trim(left(put(t904,best12.))));
call symput(  'ar2'||left(i),trim(left(put(arom4,best12.))));
call symput(  'ol2'||left(i),trim(left(put(olef4,best12.))));
call symput('oxox2'||left(i),trim(left(put(oxox4,best12.))));
call symput('rvrv2'||left(i),trim(left(put(rvrv4,best12.))));
call symput('rvar2'||left(i),trim(left(put(rvar4,best12.))));
call symput('rvol2'||left(i),trim(left(put(rvol4,best12.))));
call symput('rvt92'||left(i),trim(left(put(rvt94,best12.))));
call symput('arsu2'||left(i),trim(left(put(arsu4,best12.))));
call symput('arar2'||left(i),trim(left(put(arar4,best12.))));
call symput('olol2'||left(i),trim(left(put(olol4,best12.))));
call symput('susu2'||left(i),trim(left(put(susu4,best12.))));
call symput('t9su2'||left(i),trim(left(put(t9su4,best12.))));
call symput('rvsu2'||left(i),trim(left(put(rvsu4,best12.))));
call symput('rvt52'||left(i),trim(left(put(rvt54,best12.))));
call symput('arol2'||left(i),trim(left(put(arol4,best12.))));
call symput('t5ar2'||left(i),trim(left(put(t5ar4,best12.))));
call symput('t9ar2'||left(i),trim(left(put(t9ar4,best12.))));
call symput('rvox2'||left(i),trim(left(put(rvox4,best12.))));
call symput('olox2'||left(i),trim(left(put(olox4,best12.))));
call symput('olt52'||left(i),trim(left(put(olt54,best12.))));
call symput('t9ol2'||left(i),trim(left(put(t9ol4,best12.))));
call symput('olsu2'||left(i),trim(left(put(olsu4,best12.))));
call symput('t5ox2'||left(i),trim(left(put(t5ox4,best12.))));
call symput('t5t92'||left(i),trim(left(put(t5t94,best12.))));
call symput('t5su2'||left(i),trim(left(put(t5su4,best12.))));
call symput('t5t52'||left(i),trim(left(put(t5t54,best12.))));
call symput('t9ox2'||left(i),trim(left(put(t9ox4,best12.))));
call symput('t9t92'||left(i),trim(left(put(t9t94,best12.))));
call symput('suox2'||left(i),trim(left(put(suox4,best12.))));
call symput('arox2'||left(i),trim(left(put(arox4,best12.))));

run;

data _null_;
set olef;
i=_n_-1;
call symput(  'rv3'||left(i),trim(left(put(rvp4,best12.))));
call symput(  'su3'||left(i),trim(left(put(sulfur4,best12.))));
call symput(  'ox3'||left(i),trim(left(put(oxygen4,best12.))));
call symput(  't53'||left(i),trim(left(put(t504,best12.))));
call symput(  't93'||left(i),trim(left(put(t904,best12.))));
call symput(  'ar3'||left(i),trim(left(put(arom4,best12.))));
call symput(  'ol3'||left(i),trim(left(put(olef4,best12.))));
call symput('oxox3'||left(i),trim(left(put(oxox4,best12.))));
call symput('rvrv3'||left(i),trim(left(put(rvrv4,best12.))));
call symput('rvar3'||left(i),trim(left(put(rvar4,best12.))));
call symput('rvol3'||left(i),trim(left(put(rvol4,best12.))));
call symput('rvt93'||left(i),trim(left(put(rvt94,best12.))));
call symput('arsu3'||left(i),trim(left(put(arsu4,best12.))));
call symput('arar3'||left(i),trim(left(put(arar4,best12.))));
call symput('olol3'||left(i),trim(left(put(olol4,best12.))));
call symput('susu3'||left(i),trim(left(put(susu4,best12.))));
call symput('t9su3'||left(i),trim(left(put(t9su4,best12.))));
call symput('rvsu3'||left(i),trim(left(put(rvsu4,best12.))));
call symput('rvt53'||left(i),trim(left(put(rvt54,best12.))));
call symput('arol3'||left(i),trim(left(put(arol4,best12.))));
call symput('t5ar3'||left(i),trim(left(put(t5ar4,best12.))));
call symput('t9ar3'||left(i),trim(left(put(t9ar4,best12.))));
call symput('rvox3'||left(i),trim(left(put(rvox4,best12.))));
call symput('olox3'||left(i),trim(left(put(olox4,best12.))));
call symput('olt53'||left(i),trim(left(put(olt54,best12.))));
call symput('t9ol3'||left(i),trim(left(put(t9ol4,best12.))));
call symput('olsu3'||left(i),trim(left(put(olsu4,best12.))));
call symput('t5ox3'||left(i),trim(left(put(t5ox4,best12.))));
call symput('t5t93'||left(i),trim(left(put(t5t94,best12.))));
call symput('t5su3'||left(i),trim(left(put(t5su4,best12.))));
call symput('t5t53'||left(i),trim(left(put(t5t54,best12.))));
call symput('t9ox3'||left(i),trim(left(put(t9ox4,best12.))));
call symput('t9t93'||left(i),trim(left(put(t9t94,best12.))));
call symput('suox3'||left(i),trim(left(put(suox4,best12.))));
call symput('arox3'||left(i),trim(left(put(arox4,best12.))));

run;

data _null_;
set sulfur;
i=_n_-1;
call symput(  'rv4'||left(i),trim(left(put(rvp4,best12.))));
call symput(  'su4'||left(i),trim(left(put(sulfur4,best12.))));
call symput(  'ox4'||left(i),trim(left(put(oxygen4,best12.))));
call symput(  't54'||left(i),trim(left(put(t504,best12.))));
call symput(  't94'||left(i),trim(left(put(t904,best12.))));
call symput(  'ar4'||left(i),trim(left(put(arom4,best12.))));
call symput(  'ol4'||left(i),trim(left(put(olef4,best12.))));
call symput('oxox4'||left(i),trim(left(put(oxox4,best12.))));
call symput('rvrv4'||left(i),trim(left(put(rvrv4,best12.))));
call symput('rvar4'||left(i),trim(left(put(rvar4,best12.))));
call symput('rvol4'||left(i),trim(left(put(rvol4,best12.))));
call symput('rvt94'||left(i),trim(left(put(rvt94,best12.))));
call symput('arsu4'||left(i),trim(left(put(arsu4,best12.))));
call symput('arar4'||left(i),trim(left(put(arar4,best12.))));
call symput('olol4'||left(i),trim(left(put(olol4,best12.))));
call symput('susu4'||left(i),trim(left(put(susu4,best12.))));
call symput('t9su4'||left(i),trim(left(put(t9su4,best12.))));
call symput('rvsu4'||left(i),trim(left(put(rvsu4,best12.))));
call symput('rvt54'||left(i),trim(left(put(rvt54,best12.))));
call symput('arol4'||left(i),trim(left(put(arol4,best12.))));
call symput('t5ar4'||left(i),trim(left(put(t5ar4,best12.))));
call symput('t9ar4'||left(i),trim(left(put(t9ar4,best12.))));
call symput('rvox4'||left(i),trim(left(put(rvox4,best12.))));
call symput('olox4'||left(i),trim(left(put(olox4,best12.))));
call symput('olt54'||left(i),trim(left(put(olt54,best12.))));
call symput('t9ol4'||left(i),trim(left(put(t9ol4,best12.))));
call symput('olsu4'||left(i),trim(left(put(olsu4,best12.))));
call symput('t5ox4'||left(i),trim(left(put(t5ox4,best12.))));
call symput('t5t94'||left(i),trim(left(put(t5t94,best12.))));
call symput('t5su4'||left(i),trim(left(put(t5su4,best12.))));
call symput('t5t54'||left(i),trim(left(put(t5t54,best12.))));
call symput('t9ox4'||left(i),trim(left(put(t9ox4,best12.))));
call symput('t9t94'||left(i),trim(left(put(t9t94,best12.))));
call symput('suox4'||left(i),trim(left(put(suox4,best12.))));
call symput('arox4'||left(i),trim(left(put(arox4,best12.))));

run;

data _null_;
set arom;
i=_n_-1;
call symput(  'rv5'||left(i),trim(left(put(rvp4,best12.))));
call symput(  'su5'||left(i),trim(left(put(sulfur4,best12.))));
call symput(  'ox5'||left(i),trim(left(put(oxygen4,best12.))));
call symput(  't55'||left(i),trim(left(put(t504,best12.))));
call symput(  't95'||left(i),trim(left(put(t904,best12.))));
call symput(  'ar5'||left(i),trim(left(put(arom4,best12.))));
call symput(  'ol5'||left(i),trim(left(put(olef4,best12.))));
call symput('oxox5'||left(i),trim(left(put(oxox4,best12.))));
call symput('rvrv5'||left(i),trim(left(put(rvrv4,best12.))));
call symput('rvar5'||left(i),trim(left(put(rvar4,best12.))));
call symput('rvol5'||left(i),trim(left(put(rvol4,best12.))));
call symput('rvt95'||left(i),trim(left(put(rvt94,best12.))));
call symput('arsu5'||left(i),trim(left(put(arsu4,best12.))));
call symput('arar5'||left(i),trim(left(put(arar4,best12.))));
call symput('olol5'||left(i),trim(left(put(olol4,best12.))));
call symput('susu5'||left(i),trim(left(put(susu4,best12.))));
call symput('t9su5'||left(i),trim(left(put(t9su4,best12.))));
call symput('rvsu5'||left(i),trim(left(put(rvsu4,best12.))));
call symput('rvt55'||left(i),trim(left(put(rvt54,best12.))));
call symput('arol5'||left(i),trim(left(put(arol4,best12.))));
call symput('t5ar5'||left(i),trim(left(put(t5ar4,best12.))));
call symput('t9ar5'||left(i),trim(left(put(t9ar4,best12.))));
call symput('rvox5'||left(i),trim(left(put(rvox4,best12.))));
call symput('olox5'||left(i),trim(left(put(olox4,best12.))));
call symput('olt55'||left(i),trim(left(put(olt54,best12.))));
call symput('t9ol5'||left(i),trim(left(put(t9ol4,best12.))));
call symput('olsu5'||left(i),trim(left(put(olsu4,best12.))));
call symput('t5ox5'||left(i),trim(left(put(t5ox4,best12.))));
call symput('t5t95'||left(i),trim(left(put(t5t94,best12.))));
call symput('t5su5'||left(i),trim(left(put(t5su4,best12.))));
call symput('t5t55'||left(i),trim(left(put(t5t54,best12.))));
call symput('t9ox5'||left(i),trim(left(put(t9ox4,best12.))));
call symput('t9t95'||left(i),trim(left(put(t9t94,best12.))));
call symput('suox5'||left(i),trim(left(put(suox4,best12.))));
call symput('arox5'||left(i),trim(left(put(arox4,best12.))));

run;

data _null_;
set t50;
i=_n_-1;
call symput(  'rv6'||left(i),trim(left(put(rvp4,best12.))));
call symput(  'su6'||left(i),trim(left(put(sulfur4,best12.))));
call symput(  'ox6'||left(i),trim(left(put(oxygen4,best12.))));
call symput(  't56'||left(i),trim(left(put(t504,best12.))));
call symput(  't96'||left(i),trim(left(put(t904,best12.))));
call symput(  'ar6'||left(i),trim(left(put(arom4,best12.))));
call symput(  'ol6'||left(i),trim(left(put(olef4,best12.))));
call symput('oxox6'||left(i),trim(left(put(oxox4,best12.))));
call symput('rvrv6'||left(i),trim(left(put(rvrv4,best12.))));
call symput('rvar6'||left(i),trim(left(put(rvar4,best12.))));
call symput('rvol6'||left(i),trim(left(put(rvol4,best12.))));
call symput('rvt96'||left(i),trim(left(put(rvt94,best12.))));
call symput('arsu6'||left(i),trim(left(put(arsu4,best12.))));
call symput('arar6'||left(i),trim(left(put(arar4,best12.))));
call symput('olol6'||left(i),trim(left(put(olol4,best12.))));
call symput('susu6'||left(i),trim(left(put(susu4,best12.))));
call symput('t9su6'||left(i),trim(left(put(t9su4,best12.))));
call symput('rvsu6'||left(i),trim(left(put(rvsu4,best12.))));
call symput('rvt56'||left(i),trim(left(put(rvt54,best12.))));
call symput('arol6'||left(i),trim(left(put(arol4,best12.))));
call symput('t5ar6'||left(i),trim(left(put(t5ar4,best12.))));
call symput('t9ar6'||left(i),trim(left(put(t9ar4,best12.))));
call symput('rvox6'||left(i),trim(left(put(rvox4,best12.))));
call symput('olox6'||left(i),trim(left(put(olox4,best12.))));
call symput('olt56'||left(i),trim(left(put(olt54,best12.))));
call symput('t9ol6'||left(i),trim(left(put(t9ol4,best12.))));
call symput('olsu6'||left(i),trim(left(put(olsu4,best12.))));
call symput('t5ox6'||left(i),trim(left(put(t5ox4,best12.))));
call symput('t5t96'||left(i),trim(left(put(t5t94,best12.))));
call symput('t5su6'||left(i),trim(left(put(t5su4,best12.))));
call symput('t5t56'||left(i),trim(left(put(t5t54,best12.))));
call symput('t9ox6'||left(i),trim(left(put(t9ox4,best12.))));
call symput('t9t96'||left(i),trim(left(put(t9t94,best12.))));
call symput('suox6'||left(i),trim(left(put(suox4,best12.))));
call symput('arox6'||left(i),trim(left(put(arox4,best12.))));

run;

data _null_;
set t90;
i=_n_-1;
call symput(  'rv7'||left(i),trim(left(put(rvp4,best12.))));
call symput(  'su7'||left(i),trim(left(put(sulfur4,best12.))));
call symput(  'ox7'||left(i),trim(left(put(oxygen4,best12.))));
call symput(  't57'||left(i),trim(left(put(t504,best12.))));
call symput(  't97'||left(i),trim(left(put(t904,best12.))));
call symput(  'ar7'||left(i),trim(left(put(arom4,best12.))));
call symput(  'ol7'||left(i),trim(left(put(olef4,best12.))));
call symput('oxox7'||left(i),trim(left(put(oxox4,best12.))));
call symput('rvrv7'||left(i),trim(left(put(rvrv4,best12.))));
call symput('rvar7'||left(i),trim(left(put(rvar4,best12.))));
call symput('rvol7'||left(i),trim(left(put(rvol4,best12.))));
call symput('rvt97'||left(i),trim(left(put(rvt94,best12.))));
call symput('arsu7'||left(i),trim(left(put(arsu4,best12.))));
call symput('arar7'||left(i),trim(left(put(arar4,best12.))));
call symput('olol7'||left(i),trim(left(put(olol4,best12.))));
call symput('susu7'||left(i),trim(left(put(susu4,best12.))));
call symput('t9su7'||left(i),trim(left(put(t9su4,best12.))));
call symput('rvsu7'||left(i),trim(left(put(rvsu4,best12.))));
call symput('rvt57'||left(i),trim(left(put(rvt54,best12.))));
call symput('arol7'||left(i),trim(left(put(arol4,best12.))));
call symput('t5ar7'||left(i),trim(left(put(t5ar4,best12.))));
call symput('t9ar7'||left(i),trim(left(put(t9ar4,best12.))));
call symput('rvox7'||left(i),trim(left(put(rvox4,best12.))));
call symput('olox7'||left(i),trim(left(put(olox4,best12.))));
call symput('olt57'||left(i),trim(left(put(olt54,best12.))));
call symput('t9ol7'||left(i),trim(left(put(t9ol4,best12.))));
call symput('olsu7'||left(i),trim(left(put(olsu4,best12.))));
call symput('t5ox7'||left(i),trim(left(put(t5ox4,best12.))));
call symput('t5t97'||left(i),trim(left(put(t5t94,best12.))));
call symput('t5su7'||left(i),trim(left(put(t5su4,best12.))));
call symput('t5t57'||left(i),trim(left(put(t5t54,best12.))));
call symput('t9ox7'||left(i),trim(left(put(t9ox4,best12.))));
call symput('t9t97'||left(i),trim(left(put(t9t94,best12.))));
call symput('suox7'||left(i),trim(left(put(suox4,best12.))));
call symput('arox7'||left(i),trim(left(put(arox4,best12.))));

run;

%macro esthc;
/*
MODEL LN_THC = RV T5 T9 AR OL OX SU
               T5T5 T9AR T9OX T9T9 ARAR T9SU SUSU RVRV
*/


%do i=0 %to 70;
estimate '' rv &&rv1&i t5 &&t51&i t9 &&t91&i ar &&ar1&i ol &&ol1&i
ox &&ox1&i su &&su1&i
t5t5 &&t5t51&i t9ar &&t9ar1&i t9ox &&t9ox1&i t9t9 &&t9t91&i
arar &&arar1&i t9su &&t9su1&i susu &&susu1&i rvrv &&rvrv1&i
/cl;
%end;


%do i=0 %to 120;
estimate '' rv &&rv2&i t5 &&t52&i t9 &&t92&i ar &&ar2&i ol &&ol2&i
ox &&ox2&i su &&su2&i
t5t5 &&t5t52&i t9ar &&t9ar2&i t9ox &&t9ox2&i t9t9 &&t9t92&i
arar &&arar2&i t9su &&t9su2&i susu &&susu2&i rvrv &&rvrv2&i
/cl;
%end;

%do i=0 %to 50;
estimate '' rv &&rv3&i t5 &&t53&i t9 &&t93&i ar &&ar3&i ol &&ol3&i
ox &&ox3&i su &&su3&i
t5t5 &&t5t53&i t9ar &&t9ar3&i t9ox &&t9ox3&i t9t9 &&t9t93&i
arar &&arar3&i t9su &&t9su3&i susu &&susu3&i rvrv &&rvrv3&i
/cl;
%end;


%do i=0 %to 80;
estimate '' rv &&rv4&i t5 &&t54&i t9 &&t94&i ar &&ar4&i ol &&ol4&i
ox &&ox4&i su &&su4&i
t5t5 &&t5t54&i t9ar &&t9ar4&i t9ox &&t9ox4&i t9t9 &&t9t94&i
arar &&arar4&i t9su &&t9su4&i susu &&susu4&i rvrv &&rvrv4&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv5&i t5 &&t55&i t9 &&t95&i ar &&ar5&i ol &&ol5&i
ox &&ox5&i su &&su5&i
t5t5 &&t5t55&i t9ar &&t9ar5&i t9ox &&t9ox5&i t9t9 &&t9t95&i
arar &&arar5&i t9su &&t9su5&i susu &&susu5&i rvrv &&rvrv5&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv6&i t5 &&t56&i t9 &&t96&i ar &&ar6&i ol &&ol6&i
ox &&ox6&i su &&su6&i
t5t5 &&t5t56&i t9ar &&t9ar6&i t9ox &&t9ox6&i t9t9 &&t9t96&i
arar &&arar6&i t9su &&t9su6&i susu &&susu6&i rvrv &&rvrv6&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv7&i t5 &&t57&i t9 &&t97&i ar &&ar7&i ol &&ol7&i
ox &&ox7&i su &&su7&i
t5t5 &&t5t57&i t9ar &&t9ar7&i t9ox &&t9ox7&i t9t9 &&t9t97&i
arar &&arar7&i t9su &&t9su7&i susu &&susu7&i rvrv &&rvrv7&i
/cl;
%end;

%mend esthc;


%macro three;
/*
MODEL LN_NOX = RV T5 T9 AR OL OX SU
               T9SU OXOX AROX
*/


%do i=0 %to 70;
estimate '' rv &&rv1&i t5 &&t51&i t9 &&t91&i ar &&ar1&i ol &&ol1&i
ox &&ox1&i su &&su1&i
t9su &&t9su1&i oxox &&oxox1&i arox &&arox1&i
/cl;
%end;

%do i=0 %to 120;
estimate '' rv &&rv2&i t5 &&t52&i t9 &&t92&i ar &&ar2&i ol &&ol2&i
ox &&ox2&i su &&su2&i
t9su &&t9su2&i oxox &&oxox2&i arox &&arox2&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv3&i t5 &&t53&i t9 &&t93&i ar &&ar3&i ol &&ol3&i
ox &&ox3&i su &&su3&i
t9su &&t9su3&i oxox &&oxox3&i arox &&arox3&i
/cl;
%end;


%do i=0 %to 80;
estimate '' rv &&rv4&i t5 &&t54&i t9 &&t94&i ar &&ar4&i ol &&ol4&i
ox &&ox4&i su &&su4&i
t9su &&t9su4&i oxox &&oxox4&i arox &&arox4&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv5&i t5 &&t55&i t9 &&t95&i ar &&ar5&i ol &&ol5&i
ox &&ox5&i su &&su5&i
t9su &&t9su5&i oxox &&oxox5&i arox &&arox5&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv6&i t5 &&t56&i t9 &&t96&i ar &&ar6&i ol &&ol6&i
ox &&ox6&i su &&su6&i
t9su &&t9su6&i oxox &&oxox6&i arox &&arox6&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv7&i t5 &&t57&i t9 &&t97&i ar &&ar7&i ol &&ol7&i
ox &&ox7&i su &&su7&i
t9su &&t9su7&i oxox &&oxox7&i arox &&arox7&i
/cl;
%end;
%mend three;

%macro zero;
/*
MODEL LN_NOX = RV T5 T9 AR OL OX SU

*/


%do i=0 %to 70;
estimate '' rv &&rv1&i t5 &&t51&i t9 &&t91&i ar &&ar1&i ol &&ol1&i
ox &&ox1&i su &&su1&i
/cl;
%end;

%do i=0 %to 120;
estimate '' rv &&rv2&i t5 &&t52&i t9 &&t92&i ar &&ar2&i ol &&ol2&i
ox &&ox2&i su &&su2&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv3&i t5 &&t53&i t9 &&t93&i ar &&ar3&i ol &&ol3&i
ox &&ox3&i su &&su3&i
/cl;
%end;


%do i=0 %to 80;
estimate '' rv &&rv4&i t5 &&t54&i t9 &&t94&i ar &&ar4&i ol &&ol4&i
ox &&ox4&i su &&su4&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv5&i t5 &&t55&i t9 &&t95&i ar &&ar5&i ol &&ol5&i
ox &&ox5&i su &&su5&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv6&i t5 &&t56&i t9 &&t96&i ar &&ar6&i ol &&ol6&i
ox &&ox6&i su &&su6&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv7&i t5 &&t57&i t9 &&t97&i ar &&ar7&i ol &&ol7&i
ox &&ox7&i su &&su7&i
/cl;
%end;

%mend zero;

%macro arox;
/*
MODEL LN_NOX = RV T5 T9 AR OL OX SU
               AROX
*/


%do i=0 %to 70;
estimate '' rv &&rv1&i t5 &&t51&i t9 &&t91&i ar &&ar1&i ol &&ol1&i
ox &&ox1&i su &&su1&i
arox &&arox1&i
/cl;
%end;

%do i=0 %to 120;
estimate '' rv &&rv2&i t5 &&t52&i t9 &&t92&i ar &&ar2&i ol &&ol2&i
ox &&ox2&i su &&su2&i
arox &&arox2&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv3&i t5 &&t53&i t9 &&t93&i ar &&ar3&i ol &&ol3&i
ox &&ox3&i su &&su3&i
arox &&arox3&i
/cl;
%end;


%do i=0 %to 80;
estimate '' rv &&rv4&i t5 &&t54&i t9 &&t94&i ar &&ar4&i ol &&ol4&i
ox &&ox4&i su &&su4&i
arox &&arox4&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv5&i t5 &&t55&i t9 &&t95&i ar &&ar5&i ol &&ol5&i
ox &&ox5&i su &&su5&i
arox &&arox5&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv6&i t5 &&t56&i t9 &&t96&i ar &&ar6&i ol &&ol6&i
ox &&ox6&i su &&su6&i
arox &&arox6&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv7&i t5 &&t57&i t9 &&t97&i ar &&ar7&i ol &&ol7&i
ox &&ox7&i su &&su7&i
arox &&arox7&i
/cl;
%end;
%mend arox;
%macro rvox;
/*
MODEL LN_NOX = RV T5 T9 AR OL OX SU
               RVOX
*/


%do i=0 %to 70;
estimate '' rv &&rv1&i t5 &&t51&i t9 &&t91&i ar &&ar1&i ol &&ol1&i
ox &&ox1&i su &&su1&i
rvox &&rvox1&i
/cl;
%end;

%do i=0 %to 120;
estimate '' rv &&rv2&i t5 &&t52&i t9 &&t92&i ar &&ar2&i ol &&ol2&i
ox &&ox2&i su &&su2&i
rvox &&rvox2&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv3&i t5 &&t53&i t9 &&t93&i ar &&ar3&i ol &&ol3&i
ox &&ox3&i su &&su3&i
rvox &&rvox3&i
/cl;
%end;


%do i=0 %to 80;
estimate '' rv &&rv4&i t5 &&t54&i t9 &&t94&i ar &&ar4&i ol &&ol4&i
ox &&ox4&i su &&su4&i
rvox &&rvox4&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv5&i t5 &&t55&i t9 &&t95&i ar &&ar5&i ol &&ol5&i
ox &&ox5&i su &&su5&i
rvox &&rvox5&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv6&i t5 &&t56&i t9 &&t96&i ar &&ar6&i ol &&ol6&i
ox &&ox6&i su &&su6&i
rvox &&rvox6&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv7&i t5 &&t57&i t9 &&t97&i ar &&ar7&i ol &&ol7&i
ox &&ox7&i su &&su7&i
rvox &&rvox7&i
/cl;
%end;
%mend rvox;


%macro speci6;
/*
MODEL LN_NOX = RV T5 T9 AR OL OX SU
               AROX RVOX
*/


%do i=0 %to 70;
estimate '' rv &&rv1&i t5 &&t51&i t9 &&t91&i ar &&ar1&i ol &&ol1&i
ox &&ox1&i su &&su1&i
arox &&arox1&i rvox &&rvox1&i
/cl;
%end;

%do i=0 %to 120;
estimate '' rv &&rv2&i t5 &&t52&i t9 &&t92&i ar &&ar2&i ol &&ol2&i
ox &&ox2&i su &&su2&i
arox &&arox2&i rvox &&rvox2&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv3&i t5 &&t53&i t9 &&t93&i ar &&ar3&i ol &&ol3&i
ox &&ox3&i su &&su3&i
arox &&arox3&i rvox &&rvox3&i
/cl;
%end;


%do i=0 %to 80;
estimate '' rv &&rv4&i t5 &&t54&i t9 &&t94&i ar &&ar4&i ol &&ol4&i
ox &&ox4&i su &&su4&i
arox &&arox4&i rvox &&rvox4&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv5&i t5 &&t55&i t9 &&t95&i ar &&ar5&i ol &&ol5&i
ox &&ox5&i su &&su5&i
arox &&arox5&i rvox &&rvox5&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv6&i t5 &&t56&i t9 &&t96&i ar &&ar6&i ol &&ol6&i
ox &&ox6&i su &&su6&i
arox &&arox6&i rvox &&rvox6&i
/cl;
%end;


%do i=0 %to 50;
estimate '' rv &&rv7&i t5 &&t57&i t9 &&t97&i ar &&ar7&i ol &&ol7&i
ox &&ox7&i su &&su7&i
arox &&arox7&i rvox &&rvox7&i
/cl;
%end;
%mend speci6;



%macro estprint(modnum);


data prd&modnum;
set preds;
number=_n_;
     if number <= 71  then x = (number-1)/20;
else if number <= 192 then x = (number - 72)/100 + 6.4;
else if number <= 243 then x = (number - 193)/5;
else if number <= 324 then x = (number - 244);
else if number <= 375 then x = (number - 325)/2 + 10;
else if number <= 426 then x = (number - 376) + 180;
else if number <= 477 then x = (number - 427) + 280;
per&modnum=100* ( exp(est)-1);
low&modnum=100* ( exp(lower)-1);
upp&modnum=100* ( exp(upper)-1);
se&modnum=100*se;
     if number <= 71  then type = "OXY";
else if number <= 192 then type = "RVP";
else if number <= 243 then type = "OLE";
else if number <= 324 then type = "SUL";
else if number <= 375 then type = "ARO";
else if number <= 426 then type = "T50";
else if number <= 477 then type = "T90";
run;

proc sort data=prd&modnum;
by type x;
run;

proc print data=prd&modnum;
by type;
var x per&modnum low&modnum upp&modnum se&modnum;
title "predictions for model &modnum based on &data";
run;

%mend estprint;

%macro toascii;

data _null_;
merge prd1 prd2 prd3 prd4 prd5
      prd6 prd7 prd8 prd9 prd10
      prd11 prd12 prd13;
by type x;
file '..\ascii\noxmods.csv' lrecl= 300;
normwt=0.2066798;
per79=per7*normwt+per9*(1-normwt);
per710=per7*normwt+per10*(1-normwt);
per712=per7*normwt+per12*(1-normwt); 
per713=per7*normwt+per13*(1-normwt);
if _n_=1 then put
"param, x, 1, 2, 3, 4, 5, 6, 7, 8 , 9, 10, 11, 12, 13, Normal + Higher Unweighted, Normal + Higher Unweighted, Normal + Higher Weighted, Normal + Higher Weighted";
if _n_=1 then put " , , , , , , , , ";
put
type      $3. ","
x      best8. ","
per1   best8. ","
per2   best8. ","
per3   best8. ","
per4   best8. ","
per5   best8. ","
per6   best8. ","
per7   best8. ","
per8   best8. ","
per9   best8. ","
per10  best8. ","
per11  best8. ","
per12  best8. ","
per13  best8. ","
per79  best8. ","
per710 best8. ","
per712 best8. ","
per713 best8.
;
run;



%mend toascii;

%macro runmix(data, method, number, fterms, rterms, mac, weights);

PROC MIXED DATA=&data MAXITER=500 METHOD=&method NOCLPRINT ;
CLASS NEW noxcat2;
weight &weights;
TITLE "NOx model using &data with method &method and terms &fterms";

MODEL LN_NOX = RV T5 T9 AR OL OX SU
               &fterms
               /S DDFM=RES;

%if &number = 4 or &number = 5 or &number = 6 or &number = 11 or
    &number = 12 or &number=13 %then %do;
RANDOM         w RVw T5w T9w ARw OLw OXw SUw
               &rterms
               /SUB=NEW;
%end;
%else %do;
RANDOM         RV T5 T9 AR OL OX SU
               &rterms
               /SUB=NEW;
%end;
%if &number = 0 %then %do;
random int / group=noxcat2 sub=new;
%end;

%if &mac = three %then %do;
%three;
%end;
%if &mac = zero %then %do;
%zero;
%end;
%if &mac = arox %then %do;
%arox;
%end;
%if &mac = speci6 %then %do;
%speci6;
%end;
%if &mac = rvox %then %do;
%rvox;
%end;
make 'Estimate' out=preds;
/*
ods output estimates=preds solutionf=tester;
*/
run;
%estprint(&number);
%mend runmix;


%macro main;
    %runmix(may00, ml, 2, t9su oxox arox, int t9su oxox arox, three, one);
    %runmix(may00, ml, 0, noxcat2 t9su oxox arox, t9su oxox arox, three, one);
    %runmix(normal, ml, 7, t9su oxox arox, int t9su oxox arox, three, one);
    %runmix(higher, ml, 8, t9su oxox arox, int t9su oxox arox, three, one);
%mend;

%main
